# Copyright 2017, 2019, 2020 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt


from netq_agent.parsers.common.platform import PlatformRender, OK, MISSING
from netq_lib.orm.redisdb.models import OS


class BluefieldPlatformRender(PlatformRender):
    def __init__(self):
        super(BluefieldPlatformRender, self).__init__()

    def process_os_info(self, logger, os_release):
        os = OS()

        os.name = 'N/A'
        os.version = 'N/A'
        os.version_id = 'N/A'

        try:
            if os_release is not None:
                for line in os_release.splitlines():
                    if line.startswith('NAME='):
                        os.name = line.split('=')[1].strip('\"')
                    if line.startswith('VERSION='):
                        os.version = line.split('=')[1].strip('\"')
                    if line.startswith('VERSION_ID='):
                        os.version_id = line.split('=')[1].strip('\"')
        except (IndexError, ValueError) as ex:
            logger.error("Failed to process os_release output: {}".format(ex))
            raise ex

        return os

    def process_syseeprom_info(self, logger, decode_syseeprom):
        return None     # TODO: Not implemented

    def process_asic_info(self, logger, board, platform_json, platform_detect):
        return None     # TODO: Not Implemented

    def process_os_license_info(self, cmd_output, svc_status=OK, **kwargs):
        return None, None   # TODO: Not Implemented


def process_platform_info(
        logger,
        random_platform,
        platform,
        os_release,
        decode_syseeprom,
        lscpu,
        meminfo,
        platform_json,
        meminfo_dmi,
        lsblk,
        agent_version,
        platform_detect,
        is_full_state,
        app_release_info
):
    render = BluefieldPlatformRender()
    render.process_platform_info(logger, random_platform, platform,
                                 os_release, decode_syseeprom, lscpu,
                                 meminfo, platform_json, meminfo_dmi,
                                 lsblk, agent_version, platform_detect,
                                 is_full_state, app_release_info)

