# Copyright 2019 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt


import psutil
from netq_lib.orm.redisdb.models import ResourceUtil
from netq_lib.common.enums import ServiceStatus
from netq_lib.common.utils import save_fullstate
from netq_agent.parsers.common.render import BaseRender


class ResourceUtilRender(BaseRender):
    def __init__(self):
        super(ResourceUtilRender, self).__init__()
        self.model = ResourceUtil

    def parse(self, cmd_output, svc_failed=False, **kwargs):
        fullstate = kwargs.get('fullstate')
        period = kwargs.get('period')
        cpu_times = psutil.cpu_times_percent()
        cpu_util = psutil._cpu_busy_time(cpu_times)
        virtual_memory = psutil.virtual_memory()
        mem_percent_util = virtual_memory.percent
        new_resource_util_obj = ResourceUtil()
        new_resource_util_obj.interval = period
        new_resource_util_obj.cpu_utilization = cpu_util
        new_resource_util_obj.cpu_user = cpu_times.user
        new_resource_util_obj.cpu_nice = cpu_times.nice
        new_resource_util_obj.cpu_system = cpu_times.system
        new_resource_util_obj.cpu_idle = cpu_times.idle
        new_resource_util_obj.cpu_iowait = cpu_times.iowait
        new_resource_util_obj.cpu_irq = cpu_times.irq
        new_resource_util_obj.cpu_softirq = cpu_times.softirq
        new_resource_util_obj.cpu_steal = cpu_times.steal
        new_resource_util_obj.cpu_guest = cpu_times.guest
        new_resource_util_obj.cpu_guest_nice = cpu_times.guest_nice
        new_resource_util_obj.mem_utilization = mem_percent_util
        new_resource_util_obj.mem_total = virtual_memory.total
        new_resource_util_obj.mem_used = virtual_memory.used

        disk_mode = cmd_output.split(',')[0]
        if disk_mode == 'ro':
            new_resource_util_obj.is_disk_read_only = True
        else:
            new_resource_util_obj.is_disk_read_only = False

        disk_partitions = psutil.disk_partitions(all=False)
        disk_utilization_json = {}
        for sdiskpart in disk_partitions:
            disk_path = sdiskpart.device
            disk_usage = psutil.disk_usage(sdiskpart.mountpoint)
            disk_utilization_json[disk_path] = {
                'percent': disk_usage.percent,
                'total': disk_usage.total,
                'used': disk_usage.used
            }

        new_resource_util_obj.disk_utilization = disk_utilization_json

        new_resource_util_obj.save()

        resource_state_arr = []
        resource_state_arr.append(new_resource_util_obj)
        if(fullstate is True):
            save_fullstate(resource_state_arr,
                           ResourceUtil().__class__.__name__,
                           should_send_gnmi=True)

        return ServiceStatus.OK
