# Copyright 2018, 2020 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

import subprocess
from netq_lib.common.utils import subprocess_wrapper
from netq_agent.parsers.common.ports import PortsRender


class CumulusPortsRender(PortsRender):
    def __init__(self):
        super(CumulusPortsRender, self).__init__()

    @staticmethod
    def _get_ethtool_path():
        return '/sbin/ethtool'

    def ethtool_fetch_test_serial_number(self, port_name):
        test_serial_number = None
        if self.is_cl_platform:
            try:
                test_serial_number = subprocess_wrapper(
                    ['/sbin/ethtool', '-m', port_name, 'offset', '168', 'length',
                     '16', 'raw', 'on'])
            except subprocess.CalledProcessError:
                test_serial_number = None
            except UnicodeDecodeError:
                test_serial_number = None
        return test_serial_number

    @staticmethod
    def _is_optical_port(ethtool_m_dict):
        if 'Optical diagnostics support' in ethtool_m_dict and 'Yes' in ethtool_m_dict['Optical diagnostics support']:
            return True
        elif 'Transmitter technology' in ethtool_m_dict and 'Copper' not in ethtool_m_dict['Transmitter technology']:
            return True

        return False


def process_ports(cmd_output, svc_failed=False, **kwargs):
    ports_render.parse(cmd_output, svc_failed, **kwargs)


ports_render = CumulusPortsRender()
