# Copyright 2019 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

from netq_agent.parsers.common.dpkg import DpkgRender
os_version = "N/A"

class SonicDpkgRender(DpkgRender):
    def __init__(self):
        super(SonicDpkgRender, self).__init__()

    def get_os_version(self):
        global os_version
        if os_version == 'N/A':
            result = self.run_command("show version")
            if result.success and result.op:
                try:
                    for line in result.op.decode().split("\n"):
                        if 'SONiC Software Version:' in line:
                            os_version = line.split(':')[1].strip()
                except (IndexError, ValueError) as ex:
                    self._logger.error("Failed to process os info: {}".format(ex))
                    raise ex
            else:
                self._logger.info("DPKG: failed to run show version command")
        return os_version


def process_dpkg(cmd_output, svc_failed=False, **kwargs):
    parser = SonicDpkgRender()
    return parser.parse(cmd_output, svc_failed, **kwargs)
